@@ -223,7 +223,7 @@ class REMI(MIDITokenizer):
 
         # SOS & EOS
         if sos_eos_tokens:
-            vocab.add_sos_eos_to_vocab()
+            vocab.add_sos_eos()
 
         return vocab
 
@@ -256,7 +256,7 @@ class REMI(MIDITokenizer):
             dic['Position'] += ['Chord']
 
         if self.additional_tokens['Tempo']:
-            dic['Tempo'] = ['Chord', 'Pitch'] if self.additional_tokens['Chord'] else ['Chord']
+            dic['Tempo'] = ['Chord', 'Pitch'] if self.additional_tokens['Chord'] else ['Pitch']
             dic['Position'] += ['Tempo']
 
         if self.additional_tokens['Rest']:
@@ -283,10 +283,7 @@ class REMI(MIDITokenizer):
         current_pitches = []
 
         def check(tok: int):
-            nonlocal err
-            nonlocal previous_type
-            nonlocal current_pos
-            nonlocal current_pitches
+            nonlocal err, previous_type, current_pos, current_pitches
             token_type, token_value = self.vocab.token_to_event[tok].split('_')
 
             # Good token type
